# Generated by Django 3.0.8 on 2020-07-13 09:48

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("utm_tracker", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="leadsource",
            name="created_at",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="When the event was recorded.",
            ),
        ),
    ]
